@@ -5,7 +5,7 @@ use strict;
 use UNIVERSAL::require;
 
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 
 use base qw(Class::Accessor::Complex Class::Accessor::Constructor);
@@ -73,9 +73,11 @@ Text::Pipe::Base - Base class for text pipe segments
 
     package Text::Pipe::My::Segment;
 
-    use base 'Text::Pipe::Base'
+    use base 'Text::Pipe::Base';
 
-    sub filter { ... }
+    sub filter {
+        # blah
+    }
 
 =head1 DESCRIPTION
 
@@ -91,7 +93,7 @@ this:
 
 =over 4
 
-=item new
+=item C<new>
 
     my $obj = Text::Pipe::Base->new;
     my $obj = Text::Pipe::Base->new(%args);
@@ -102,24 +104,24 @@ component is initialized by calling the method of the same name with the given
 value. If called with a single hash reference, it is dereferenced and its
 key/value pairs are set as described before.
 
-=item bit_or
+=item C<bit_or>
 
 This subroutine implements the pipe stacking that is invoked by using the C<|>
 operator, as in:
 
     my $stackable_pipe = $pipe1 | $pipe2 | $pipe3;
 
-=item filter
+=item C<filter>
 
 Can filter a single string or an reference to an array of strings. Each string
 is filtered using C<filter_single()>.
 
-=item filter_single
+=item C<filter_single>
 
 Filters a single string. In this base class this method just returns the input
 string unaltered.
 
-=item init
+=item C<init>
 
 This method is called by the constructor and passed the object so it can be
 initialized. In this class the method is empty, but it exists so that
@@ -210,11 +212,15 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by the authors.
+Copyright 2007-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+If you are looking for the Windows software 'TextPipe Pro', go to
+http://www.datamystic.com/ - this Perl module has nothing to do with it.
 
 =cut
 
